@@ -115,33 +115,41 @@ def flip_axis(x, axis):
     return x
 
 
-def get_all_ct_names(path, number=None, prefix=None, name_suffix=None):
-    suffix_list = [".nrrd", ".mhd", ".mha", ".nii", ".nii.gz"]  # todo: more suffix
-
-    if prefix and name_suffix:
-        files = glob.glob(path + '/' + prefix + "*" + name_suffix + suffix_list[0])
-        for suffix in suffix_list[1:]:
-            files.extend(glob.glob(path + '/' + prefix + "*" + name_suffix + suffix))
-    elif prefix:
-        files = glob.glob(path + '/' + prefix + "*" + suffix_list[0])
-        for suffix in suffix_list[1:]:
-            files.extend(glob.glob(path + '/' + prefix + "*" + suffix))
-    elif name_suffix:
-        if 'SSc' in path:
-            files = glob.glob(path + '/*/' + "*" + name_suffix + '.mha')
+def get_all_ct_names(path, number=None, prefix=None, suffix=None, extension=None):
+    if extension is None:
+        extension_list = [".nrrd", ".mhd", ".mha", ".nii", ".nii.gz"]  # todo: more suffix
+    else:
+        if type(extension) is list and type(extension[0]) is str:
+            extension_list = extension
+        elif type(extension) is str:
+            extension_list = [extension]
         else:
-            files = glob.glob(path + '/' + "*" + name_suffix + suffix_list[0])
-            for suffix in suffix_list[1:]:
-                files.extend(glob.glob(path + '/' + "*" + name_suffix + suffix))
+            raise Exception('the extension type is wrong. Please use a string or a list of string.')
+
+    if prefix and suffix:
+        files = glob.glob(path + '/' + prefix + "*" + suffix + extension_list[0])
+        for suffix in extension_list[1:]:
+            files.extend(glob.glob(path + '/' + prefix + "*" + suffix + suffix))
+    elif prefix:
+        files = glob.glob(path + '/' + prefix + "*" + extension_list[0])
+        for suffix in extension_list[1:]:
+            files.extend(glob.glob(path + '/' + prefix + "*" + suffix))
+    elif suffix:
+        if 'SSc' in path:
+            files = glob.glob(path + '/*/' + "*" + suffix + '.mha')
+        else:
+            files = glob.glob(path + '/' + "*" + suffix + extension_list[0])
+            for suffix in extension_list[1:]:
+                files.extend(glob.glob(path + '/' + "*" + suffix + suffix))
 
     else:
-        files = glob.glob(path + '/*' + suffix_list[0])
-        for suffix in suffix_list[1:]:
+        files = glob.glob(path + '/*' + extension_list[0])
+        for suffix in extension_list[1:]:
             files.extend(glob.glob(path + '/*' + suffix))
 
     scan_files = sorted(files)
     if len(scan_files) == 0:
-        raise Exception('Scan files are None, please check the data directory')
+        raise Exception(f'Scan files are None, please check the data directory: {path}')
     if isinstance(number, int) and number != 0:
         scan_files = scan_files[:number]
     elif isinstance(number, list):  # number = [3,7]
@@ -155,14 +163,14 @@ def get_ct_pair_filenames(gdth_path, pred_path):
     pred_files = get_all_ct_names(pred_path)
 
     if len(gdth_files) == 0:
-        raise Exception('ground truth files  are None, Please check the directories', gdth_path)
+        raise Exception('ground truth files  are None, Please check the directories: ', gdth_path)
     if len(pred_files) == 0:
-        raise Exception(' predicted files are None, Please check the directories', pred_path)
+        raise Exception('predicted files are None, Please check the directories: ', pred_path)
 
-    if any(['fissure' in file for file in pred_files]):  # check no fissure files are included
-        fissure_gdth, fissure_pred = get_fissure_filenames(gdth_path, pred_path)
-        gdth_files = set(gdth_files) - set(fissure_gdth)
-        pred_files = set(pred_files) - set(fissure_pred)
+    # if any(['fissure' in file for file in pred_files]):  # check no fissure files are included
+    #     fissure_gdth, fissure_pred = get_fissure_filenames(gdth_path, pred_path)
+    #     gdth_files = set(gdth_files) - set(fissure_gdth)
+    #     pred_files = set(pred_files) - set(fissure_pred)
     gdth_files, pred_files = get_intersection_files(gdth_files, pred_files)
 
     return gdth_files, pred_files
@@ -173,7 +181,8 @@ def recall(seg, gt):
     im2 = np.asarray(gt > 0).astype(np.bool)
 
     if im1.shape != im2.shape:
-        raise ValueError("Shape mismatch: im1 and im2 must have the same shape.")
+        raise ValueError(f"Shape mismatch: im1 and im2 must have the same shape, but the im1.shape is {im1.shape} and "
+                         f"im2.shape is {im2.shape}")
 
     intersection = np.logical_and(im1, im2).astype(float)
 
@@ -227,11 +236,11 @@ def get_intersection_files(gdth_files, pred_files):
     return sorted(new_gdth_files), sorted(new_pred_files)
 
 
-def get_gdth_pred_names(gdth_path, pred_path, fissure=False, fissureradius=1):
-    if fissure:
-        gdth_files, pred_files = get_fissure_filenames(gdth_path, pred_path, fissureradius=fissureradius)
-    else:
-        gdth_files, pred_files = get_ct_pair_filenames(gdth_path, pred_path)
+def get_gdth_pred_names(gdth_path, pred_path):
+    # if fissure:
+    #     gdth_files, pred_files = get_fissure_filenames(gdth_path, pred_path, fissureradius=fissureradius)
+    # else:
+    gdth_files, pred_files = get_ct_pair_filenames(gdth_path, pred_path)
 
     return gdth_files, pred_files
 
@@ -268,7 +277,6 @@ def load_itk(filename, require_ori_sp=False):
         return ct_scan
     
 
-# %%
 def save_itk(filename, scan, origin, spacing, dtype='int16'):
     """
     Save a array to itk file.
@@ -287,12 +295,13 @@ def save_itk(filename, scan, origin, spacing, dtype='int16'):
     # numpy array is reversed after convertion from image, but origin and spacing keep unchanged
     stk.SetSpacing(spacing[::-1])
 
-    writer = sitk.ImageFileWriter()
-    writer.SetFileName(filename)
-    writer.Execute(stk)
+    sitk.WriteImage(stk, filename, useCompression=True)
+
+    # writer = sitk.ImageFileWriter()
+    # writer.SetFileName(filename)
+    # writer.Execute(stk)
 
 
-# %%
 def normalize(image, min_=-1000.0, max_=400.0):
     """
     Set the values to [0~1].
